@@ -8,6 +8,7 @@ package org.postgresql.core;
 import org.postgresql.jdbc.EscapeSyntaxCallMode;
 import org.postgresql.jdbc.EscapedFunctions2;
 import org.postgresql.util.GT;
+import org.postgresql.util.IntList;
 import org.postgresql.util.PSQLException;
 import org.postgresql.util.PSQLState;
 
@@ -28,8 +29,6 @@ import java.util.List;
  * @author Christopher Deckers (chrriis@gmail.com)
  */
 public class Parser {
-  private static final int[] NO_BINDS = new int[0];
-
   /**
    * Parses JDBC query into PostgreSQL's native format. Several queries might be given if separated
    * by semicolon.
@@ -62,7 +61,7 @@ public class Parser {
     char[] aChars = query.toCharArray();
 
     StringBuilder nativeSql = new StringBuilder(query.length() + 10);
-    List<Integer> bindPositions = null; // initialized on demand
+    IntList bindPositions = null; // initialized on demand
     List<NativeQuery> nativeQueries = null;
     boolean isCurrentReWriteCompatible = false;
     boolean isValuesFound = false;
@@ -87,7 +86,7 @@ public class Parser {
     parenthesis, ? and ;
     for single/double/dollar quotes, and comments we just want to move the index
      */
-    for (int i = 0; i < aChars.length; ++i) {
+    for (int i = 0; i < aChars.length; i++) {
       char aChar = aChars[i];
       boolean isKeyWordChar = false;
       // ';' is ignored as it splits the queries. We do have to deal with ; in BEGIN ATOMIC functions
@@ -135,7 +134,7 @@ public class Parser {
               nativeSql.append('?');
             } else {
               if (bindPositions == null) {
-                bindPositions = new ArrayList<Integer>();
+                bindPositions = new IntList();
               }
               bindPositions.add(nativeSql.length());
               int bindIndex = bindPositions.size();
@@ -161,7 +160,7 @@ public class Parser {
 
               if (splitStatements) {
                 if (nativeQueries == null) {
-                  nativeQueries = new ArrayList<NativeQuery>();
+                  nativeQueries = new ArrayList<>();
                 }
 
                 if (!isValuesFound || !isCurrentReWriteCompatible || valuesParenthesisClosePosition == -1
@@ -261,7 +260,7 @@ public class Parser {
             isBeginPresent = true;
           } else {
             // found begin, now look for atomic
-            if (isBeginPresent == true) {
+            if (isBeginPresent) {
               if (wordLength == 6 && parseAtomicKeyword(aChars, keywordStart)) {
                 isBeginAtomicPresent = true;
               }
@@ -308,7 +307,7 @@ public class Parser {
     }
 
     if (nativeSql.length() == 0) {
-      return nativeQueries != null ? nativeQueries : Collections.<NativeQuery>emptyList();
+      return nativeQueries != null ? nativeQueries : Collections.emptyList();
     }
 
     if (addReturning(nativeSql, currentCommandType, returningColumnNames, isReturningPresent, quoteReturningIdentifiers)) {
@@ -400,28 +399,24 @@ public class Parser {
       if (quoteReturningIdentifiers) {
         Utils.escapeIdentifier(nativeSql, columnName);
       } else {
-        nativeSql.append( columnName );
+        nativeSql.append(columnName);
       }
     }
     return true;
   }
 
   /**
-   * Converts {@code List<Integer>} to {@code int[]}. Empty and {@code null} lists are converted to
-   * empty array.
+   * Converts {@link IntList} to {@code int[]}. A {@code null} collection is converted to
+   * {@code null} array.
    *
    * @param list input list
    * @return output array
    */
-  private static int[] toIntArray(/* @Nullable */ List<Integer> list) {
-    if (list == null || list.isEmpty()) {
-      return NO_BINDS;
+  private static int /* @Nullable */ [] toIntArray(/* @Nullable */ IntList list) {
+    if (list == null) {
+      return null;
     }
-    int[] res = new int[list.size()];
-    for (int i = 0; i < list.size(); i++) {
-      res[i] = list.get(i); // must not be null
-    }
-    return res;
+    return list.toArray();
   }
 
   /**
@@ -449,11 +444,8 @@ public class Parser {
     if (standardConformingStrings) {
       // do NOT treat backslashes as escape characters
       while (++offset < query.length) {
-        switch (query[offset]) {
-          case '\'':
-            return offset;
-          default:
-            break;
+        if (query[offset] == '\'') {
+          return offset;
         }
       }
     } else {
@@ -507,7 +499,7 @@ public class Parser {
       if (query[offset + 1] == '$') {
         endIdx = offset + 1;
       } else if (isDollarQuoteStartChar(query[offset + 1])) {
-        for (int d = offset + 2; d < query.length; ++d) {
+        for (int d = offset + 2; d < query.length; d++) {
           if (query[d] == '$') {
             endIdx = d;
             break;
@@ -521,7 +513,7 @@ public class Parser {
         int tagIdx = offset;
         int tagLen = endIdx - offset + 1;
         offset = endIdx; // loop continues at endIdx + 1
-        for (++offset; offset < query.length; ++offset) {
+        for (++offset; offset < query.length; offset++) {
           if (query[offset] == '$'
               && subArraysEqual(query, tagIdx, offset, tagLen)) {
             offset += tagLen - 1;
@@ -565,7 +557,7 @@ public class Parser {
     if (offset + 1 < query.length && query[offset + 1] == '*') {
       // /* /* */ */ nest, according to SQL spec
       int level = 1;
-      for (offset += 2; offset < query.length; ++offset) {
+      for (offset += 2; offset < query.length; offset++) {
         switch (query[offset - 1]) {
           case '*':
             if (query[offset] == '/') {
@@ -1021,7 +1013,7 @@ public class Parser {
       return false;
     }
 
-    for (int i = 0; i < len; ++i) {
+    for (int i = 0; i < len; i++) {
       if (arr[offA + i] != arr[offB + i]) {
         return false;
       }
@@ -1115,8 +1107,8 @@ public class Parser {
           break;
 
         case 5:  // Should be at 'call ' either at start of string or after ?=
-          if ((ch == 'c' || ch == 'C') && i + 4 <= len && jdbcSql.substring(i, i + 4)
-              .equalsIgnoreCase("call")) {
+          if ((ch == 'c' || ch == 'C') && i + 4 <= len && "call"
+              .equalsIgnoreCase(jdbcSql.substring(i, i + 4))) {
             isFunction = true;
             i += 4;
             ++state;
@@ -1192,7 +1184,7 @@ public class Parser {
         if (i < len - 5) { // 5 == length of "call" + 1 whitespace
           //Check for CALL followed by whitespace
           char ch = jdbcSql.charAt(i);
-          if ((ch == 'c' || ch == 'C') && jdbcSql.substring(i, i + 4).equalsIgnoreCase("call")
+          if ((ch == 'c' || ch == 'C') && "call".equalsIgnoreCase(jdbcSql.substring(i, i + 4))
                && Character.isWhitespace(jdbcSql.charAt(i + 4))) {
             isFunction = true;
           }
@@ -1476,7 +1468,7 @@ public class Parser {
       boolean stdStrings)
       throws SQLException {
     // Maximum arity of functions in EscapedFunctions is 3
-    List<CharSequence> parsedArgs = new ArrayList<CharSequence>(3);
+    List<CharSequence> parsedArgs = new ArrayList<>(3);
     while (true) {
       StringBuilder arg = new StringBuilder();
       int lastPos = i;
