@@ -90,10 +90,12 @@ class SimpleParameterList implements V3ParameterList {
     pos = index + 1;
   }
 
+  @Override
   public /* @NonNegative */ int getParameterCount() {
     return paramValues.length;
   }
 
+  @Override
   public /* @NonNegative */ int getOutParameterCount() {
     int count = 0;
     for (int i = 0; i < paramTypes.length; i++) {
@@ -109,6 +111,7 @@ class SimpleParameterList implements V3ParameterList {
 
   }
 
+  @Override
   public /* @NonNegative */ int getInParameterCount() {
     int count = 0;
     for (int i = 0; i < paramTypes.length; i++) {
@@ -119,20 +122,24 @@ class SimpleParameterList implements V3ParameterList {
     return count;
   }
 
+  @Override
   public void setIntParameter(/* @Positive */ int index, int value) throws SQLException {
     byte[] data = new byte[4];
     ByteConverter.int4(data, 0, value);
     bind(index, data, Oid.INT4, BINARY);
   }
 
+  @Override
   public void setLiteralParameter(/* @Positive */ int index, String value, int oid) throws SQLException {
     bind(index, value, oid, TEXT);
   }
 
+  @Override
   public void setStringParameter(/* @Positive */ int index, String value, int oid) throws SQLException {
     bind(index, value, oid, TEXT);
   }
 
+  @Override
   public void setBinaryParameter(/* @Positive */ int index, byte[] value, int oid) throws SQLException {
     bind(index, value, oid, BINARY);
   }
@@ -173,6 +180,58 @@ class SimpleParameterList implements V3ParameterList {
     bind(index, NULL_OBJECT, oid, binaryTransfer);
   }
 
+  /**
+   * <p>Escapes a given text value as a literal, wraps it in single quotes, casts it to the
+   * to the given data type, and finally wraps the whole thing in parentheses.</p>
+   *
+   * <p>For example, "123" and "int4" becomes "('123'::int)"</p>
+   *
+   * <p>The additional parentheses is added to ensure that the surrounding text of where the
+   * parameter value is entered does modify the interpretation of the value.</p>
+   *
+   * <p>For example if our input SQL is: <code>SELECT ?b</code></p>
+   *
+   * <p>Using a parameter value of '{}' and type of json we'd get:</p>
+   *
+   * <pre>
+   * test=# SELECT ('{}'::json)b;
+   *  b
+   * ----
+   *  {}
+   * </pre>
+   *
+   * <p>But without the parentheses the result changes:</p>
+   *
+   * <pre>
+   * test=# SELECT '{}'::jsonb;
+   * jsonb
+   * -------
+   * {}
+   * </pre>
+   **/
+  private static String quoteAndCast(String text, /* @Nullable */ String type, boolean standardConformingStrings) {
+    StringBuilder sb = new StringBuilder((text.length() + 10) / 10 * 11); // Add 10% for escaping.
+    sb.append("('");
+    try {
+      Utils.escapeLiteral(sb, text, standardConformingStrings);
+    } catch (SQLException e) {
+      // This should only happen if we have an embedded null
+      // and there's not much we can do if we do hit one.
+      //
+      // To force a server side failure, we deliberately include
+      // a zero byte character in the literal to force the server
+      // to reject the command.
+      sb.append('\u0000');
+    }
+    sb.append("'");
+    if (type != null) {
+      sb.append("::");
+      sb.append(type);
+    }
+    sb.append(")");
+    return sb.toString();
+  }
+
   @Override
   public String toString(/* @Positive */ int index, boolean standardConformingStrings) {
     --index;
@@ -180,106 +239,109 @@ class SimpleParameterList implements V3ParameterList {
     if (paramValue == null) {
       return "?";
     } else if (paramValue == NULL_OBJECT) {
-      return "NULL";
-    } else if ((flags[index] & BINARY) == BINARY) {
+      return "(NULL)";
+    }
+    String textValue;
+    String type;
+    if ((flags[index] & BINARY) == BINARY) {
       // handle some of the numeric types
-
       switch (paramTypes[index]) {
         case Oid.INT2:
           short s = ByteConverter.int2((byte[]) paramValue, 0);
-          return Short.toString(s);
+          textValue = Short.toString(s);
+          type = "int2";
+          break;
 
         case Oid.INT4:
           int i = ByteConverter.int4((byte[]) paramValue, 0);
-          return Integer.toString(i);
+          textValue = Integer.toString(i);
+          type = "int4";
+          break;
 
         case Oid.INT8:
           long l = ByteConverter.int8((byte[]) paramValue, 0);
-          return Long.toString(l);
+          textValue = Long.toString(l);
+          type = "int8";
+          break;
 
         case Oid.FLOAT4:
           float f = ByteConverter.float4((byte[]) paramValue, 0);
           if (Float.isNaN(f)) {
-            return "'NaN'::real";
+            return "('NaN'::real)";
           }
-          return Float.toString(f);
+          textValue = Float.toString(f);
+          type = "real";
+          break;
 
         case Oid.FLOAT8:
           double d = ByteConverter.float8((byte[]) paramValue, 0);
           if (Double.isNaN(d)) {
-            return "'NaN'::double precision";
+            return "('NaN'::double precision)";
           }
-          return Double.toString(d);
+          textValue = Double.toString(d);
+          type = "double precision";
+          break;
 
         case Oid.NUMERIC:
           Number n = ByteConverter.numeric((byte[]) paramValue);
           if (n instanceof Double) {
             assert ((Double) n).isNaN();
-            return "'NaN'::numeric";
+            return "('NaN'::numeric)";
           }
-          return n.toString();
+          textValue = n.toString();
+          type = "numeric";
+          break;
 
         case Oid.UUID:
-          String uuid =
+          textValue =
               new UUIDArrayAssistant().buildElement((byte[]) paramValue, 0, 16).toString();
-          return "'" + uuid + "'::uuid";
+          type = "uuid";
+          break;
 
         case Oid.POINT:
           PGpoint pgPoint = new PGpoint();
           pgPoint.setByteValue((byte[]) paramValue, 0);
-          return "'" + pgPoint.toString() + "'::point";
+          textValue = pgPoint.toString();
+          type = "point";
+          break;
 
         case Oid.BOX:
           PGbox pgBox = new PGbox();
           pgBox.setByteValue((byte[]) paramValue, 0);
-          return "'" + pgBox.toString() + "'::box";
+          textValue = pgBox.toString();
+          type = "box";
+          break;
+
+        default:
+          return "?";
       }
-      return "?";
     } else {
-      String param = paramValue.toString();
-
-      // add room for quotes + potential escaping.
-      StringBuilder p = new StringBuilder(3 + (param.length() + 10) / 10 * 11);
-
-      // No E'..' here since escapeLiteral escapes all things and it does not use \123 kind of
-      // escape codes
-      p.append('\'');
-      try {
-        p = Utils.escapeLiteral(p, param, standardConformingStrings);
-      } catch (SQLException sqle) {
-        // This should only happen if we have an embedded null
-        // and there's not much we can do if we do hit one.
-        //
-        // The goal of toString isn't to be sent to the server,
-        // so we aren't 100% accurate (see StreamWrapper), put
-        // the unescaped version of the data.
-        //
-        p.append(param);
-      }
-      p.append('\'');
+      textValue = paramValue.toString();
       int paramType = paramTypes[index];
       if (paramType == Oid.TIMESTAMP) {
-        p.append("::timestamp");
+        type = "timestamp";
       } else if (paramType == Oid.TIMESTAMPTZ) {
-        p.append("::timestamp with time zone");
+        type = "timestamp with time zone";
       } else if (paramType == Oid.TIME) {
-        p.append("::time");
+        type = "time";
       } else if (paramType == Oid.TIMETZ) {
-        p.append("::time with time zone");
+        type = "time with time zone";
       } else if (paramType == Oid.DATE) {
-        p.append("::date");
+        type = "date";
       } else if (paramType == Oid.INTERVAL) {
-        p.append("::interval");
+        type = "interval";
       } else if (paramType == Oid.NUMERIC) {
-        p.append("::numeric");
+        type = "numeric";
+      } else {
+        type = null;
       }
-      return p.toString();
     }
+    return quoteAndCast(textValue, type, standardConformingStrings);
   }
 
   @Override
   public void checkAllParametersSet() throws SQLException {
-    for (int i = 0; i < paramTypes.length; ++i) {
+    for (int i = 0; i < paramTypes.length; i++) {
       if (direction(i) != OUT && paramValues[i] == null) {
         throw new PSQLException(GT.tr("No value specified for parameter {0}.", i + 1),
             PSQLState.INVALID_PARAMETER_VALUE);
@@ -289,7 +351,7 @@ class SimpleParameterList implements V3ParameterList {
 
   @Override
   public void convertFunctionOutParameters() {
-    for (int i = 0; i < paramTypes.length; ++i) {
+    for (int i = 0; i < paramTypes.length; i++) {
       if (direction(i) == OUT) {
         paramTypes[i] = Oid.VOID;
         paramValues[i] = NULL_OBJECT;
@@ -319,6 +381,7 @@ class SimpleParameterList implements V3ParameterList {
     pgStream.send(writer);
   }
 
+  @Override
   public int[] getTypeOIDs() {
     return paramTypes;
   }
@@ -351,7 +414,7 @@ class SimpleParameterList implements V3ParameterList {
   }
 
   boolean isNull(/* @Positive */ int index) {
-    return (paramValues[index - 1] == NULL_OBJECT);
+    return paramValues[index - 1] == NULL_OBJECT;
   }
 
   boolean isBinary(/* @Positive */ int index) {
@@ -413,7 +476,7 @@ class SimpleParameterList implements V3ParameterList {
 
     // Binary-format bytea?
     if (paramValue instanceof StreamWrapper) {
-      try (StreamWrapper streamWrapper = (StreamWrapper) paramValue;) {
+      try (StreamWrapper streamWrapper = (StreamWrapper) paramValue) {
         streamBytea(pgStream, streamWrapper);
       }
       return;
@@ -432,6 +495,7 @@ class SimpleParameterList implements V3ParameterList {
     pgStream.send(encoded[index]);
   }
 
+  @Override
   public ParameterList copy() {
     SimpleParameterList newCopy = new SimpleParameterList(paramValues.length, transferModeRegistry);
     System.arraycopy(paramValues, 0, newCopy.paramValues, 0, paramValues.length);
@@ -441,6 +505,7 @@ class SimpleParameterList implements V3ParameterList {
     return newCopy;
   }
 
+  @Override
   public void clear() {
     Arrays.fill(paramValues, null);
     Arrays.fill(paramTypes, 0);
@@ -449,29 +514,34 @@ class SimpleParameterList implements V3ParameterList {
     pos = 0;
   }
 
+  @Override
   public SimpleParameterList /* @Nullable */ [] getSubparams() {
     return null;
   }
 
+  @Override
   public /* @Nullable */ Object[] getValues() {
     return paramValues;
   }
 
+  @Override
   public int[] getParamTypes() {
     return paramTypes;
   }
 
+  @Override
   public byte[] getFlags() {
     return flags;
   }
 
+  @Override
   public byte[] /* @Nullable */ [] getEncoding() {
     return encoded;
   }
 
   @Override
   public void appendAll(ParameterList list) throws SQLException {
-    if (list instanceof org.postgresql.core.v3.SimpleParameterList ) {
+    if (list instanceof SimpleParameterList ) {
       /* only v3.SimpleParameterList is compatible with this type
       we need to create copies of our parameters, otherwise the values can be changed */
       SimpleParameterList spl = (SimpleParameterList) list;
@@ -519,5 +589,5 @@ class SimpleParameterList implements V3ParameterList {
    */
   private static final Object NULL_OBJECT = new Object();
 
-  private int pos = 0;
+  private int pos;
 }
