@@ -22,7 +22,7 @@ import java.util.Properties;
  * HostChooser that keeps track of known host statuses.
  */
 class MultiHostChooser implements HostChooser {
-  private HostSpec[] hostSpecs;
+  private final HostSpec[] hostSpecs;
   private final HostRequirement targetServerType;
   private int hostRecheckTime;
   private boolean loadBalance;
