@@ -48,10 +48,12 @@ import java.io.Writer;
 import java.math.BigDecimal;
 import java.math.BigInteger;
 import java.math.RoundingMode;
+import java.net.URL;
 import java.nio.charset.Charset;
 import java.sql.Array;
 import java.sql.Blob;
 import java.sql.Clob;
+import java.sql.Date;
 import java.sql.NClob;
 import java.sql.ParameterMetaData;
 import java.sql.PreparedStatement;
@@ -61,6 +63,7 @@ import java.sql.ResultSetMetaData;
 import java.sql.RowId;
 import java.sql.SQLException;
 import java.sql.SQLFeatureNotSupportedException;
+import java.sql.SQLType;
 import java.sql.SQLXML;
 import java.sql.Time;
 import java.sql.Timestamp;
@@ -178,6 +181,7 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     }
   }
 
+  @Override
   public boolean executeWithFlags(int flags) throws SQLException {
     try {
       try (ResourceLock ignore = lock.obtain()) {
@@ -190,13 +194,14 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
         execute(preparedQuery, preparedParameters, flags);
 
         checkClosed();
-        return (result != null && result.getResultSet() != null);
+        return result != null && result.getResultSet() != null;
       }
     } finally {
       defaultTimeZone = null;
     }
   }
 
+  @Override
   protected boolean isOneShotQuery(/* @Nullable */ CachedQuery cachedQuery) {
     if (cachedQuery == null) {
       cachedQuery = preparedQuery;
@@ -211,6 +216,7 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     }
   }
 
+  @Override
   public void setNull(int parameterIndex, int sqlType) throws SQLException {
     checkClosed();
 
@@ -293,16 +299,19 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     preparedParameters.setNull(parameterIndex, oid);
   }
 
+  @Override
   public void setBoolean(/* @Positive */ int parameterIndex, boolean x) throws SQLException {
     checkClosed();
     // The key words TRUE and FALSE are the preferred (SQL-compliant) usage.
     bindLiteral(parameterIndex, x ? "TRUE" : "FALSE", Oid.BOOL);
   }
 
+  @Override
   public void setByte(/* @Positive */ int parameterIndex, byte x) throws SQLException {
     setShort(parameterIndex, x);
   }
 
+  @Override
   public void setShort(/* @Positive */ int parameterIndex, short x) throws SQLException {
     checkClosed();
     if (connection.binaryTransferSend(Oid.INT2)) {
@@ -314,6 +323,7 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     bindLiteral(parameterIndex, Integer.toString(x), Oid.INT2);
   }
 
+  @Override
   public void setInt(/* @Positive */ int parameterIndex, int x) throws SQLException {
     checkClosed();
     if (connection.binaryTransferSend(Oid.INT4)) {
@@ -325,6 +335,7 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     bindLiteral(parameterIndex, Integer.toString(x), Oid.INT4);
   }
 
+  @Override
   public void setLong(/* @Positive */ int parameterIndex, long x) throws SQLException {
     checkClosed();
     if (connection.binaryTransferSend(Oid.INT8)) {
@@ -336,6 +347,7 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     bindLiteral(parameterIndex, Long.toString(x), Oid.INT8);
   }
 
+  @Override
   public void setFloat(/* @Positive */ int parameterIndex, float x) throws SQLException {
     checkClosed();
     if (connection.binaryTransferSend(Oid.FLOAT4)) {
@@ -347,6 +359,7 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     bindLiteral(parameterIndex, Float.toString(x), Oid.FLOAT8);
   }
 
+  @Override
   public void setDouble(/* @Positive */ int parameterIndex, double x) throws SQLException {
     checkClosed();
     if (connection.binaryTransferSend(Oid.FLOAT8)) {
@@ -358,6 +371,7 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     bindLiteral(parameterIndex, Double.toString(x), Oid.FLOAT8);
   }
 
+  @Override
   public void setBigDecimal(/* @Positive */ int parameterIndex, /* @Nullable */ BigDecimal x)
       throws SQLException {
     if (x != null && connection.binaryTransferSend(Oid.NUMERIC)) {
@@ -368,13 +382,14 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     setNumber(parameterIndex, x);
   }
 
+  @Override
   public void setString(/* @Positive */ int parameterIndex, /* @Nullable */ String x) throws SQLException {
     checkClosed();
     setString(parameterIndex, x, getStringType());
   }
 
   private int getStringType() {
-    return (connection.getStringVarcharFlag() ? Oid.VARCHAR : Oid.UNSPECIFIED);
+    return connection.getStringVarcharFlag() ? Oid.VARCHAR : Oid.UNSPECIFIED;
   }
 
   protected void setString(/* @Positive */ int parameterIndex,
@@ -388,6 +403,7 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     }
   }
 
+  @Override
   public void setBytes(/* @Positive */ int parameterIndex, byte /* @Nullable */[] x) throws SQLException {
     checkClosed();
 
@@ -407,15 +423,18 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     preparedParameters.setBytea(parameterIndex, x);
   }
 
+  @Override
   public void setDate(/* @Positive */ int parameterIndex,
-      java.sql./* @Nullable */ Date x) throws SQLException {
+      /* @Nullable */ Date x) throws SQLException {
     setDate(parameterIndex, x, null);
   }
 
+  @Override
   public void setTime(/* @Positive */ int parameterIndex, /* @Nullable */ Time x) throws SQLException {
     setTime(parameterIndex, x, null);
   }
 
+  @Override
   public void setTimestamp(/* @Positive */ int parameterIndex, /* @Nullable */ Timestamp x) throws SQLException {
     setTimestamp(parameterIndex, x, null);
   }
@@ -466,12 +485,14 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     }
   }
 
+  @Override
   public void setAsciiStream(/* @Positive */ int parameterIndex, /* @Nullable */ InputStream x,
       /* @NonNegative */ int length) throws SQLException {
     checkClosed();
     setCharacterStreamPost71(parameterIndex, x, length, "ASCII");
   }
 
+  @Override
   @SuppressWarnings("deprecation")
   public void setUnicodeStream(/* @Positive */ int parameterIndex, /* @Nullable */ InputStream x,
       /* @NonNegative */ int length) throws SQLException {
@@ -480,6 +501,7 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     setCharacterStreamPost71(parameterIndex, x, length, "UTF-8");
   }
 
+  @Override
   public void setBinaryStream(/* @Positive */ int parameterIndex, /* @Nullable */ InputStream x,
       /* @NonNegative */ int length) throws SQLException {
     checkClosed();
@@ -502,6 +524,7 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     preparedParameters.setBytea(parameterIndex, x, length);
   }
 
+  @Override
   public void clearParameters() throws SQLException {
     preparedParameters.clear();
   }
@@ -607,18 +630,18 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
         break;
       case Types.LONGVARCHAR:
         if (in instanceof InputStream) {
-          preparedParameters.setText(parameterIndex, (InputStream)in);
+          preparedParameters.setText(parameterIndex, (InputStream) in);
         } else {
           setString(parameterIndex, castToString(in), getStringType());
         }
         break;
       case Types.DATE:
-        if (in instanceof java.sql.Date) {
-          setDate(parameterIndex, (java.sql.Date) in);
+        if (in instanceof Date) {
+          setDate(parameterIndex, (Date) in);
         } else {
-          java.sql.Date tmpd;
+          Date tmpd;
           if (in instanceof java.util.Date) {
-            tmpd = new java.sql.Date(((java.util.Date) in).getTime());
+            tmpd = new Date(((java.util.Date) in).getTime());
           } else if (in instanceof LocalDate) {
             setDate(parameterIndex, (LocalDate) in);
             break;
@@ -629,12 +652,12 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
         }
         break;
       case Types.TIME:
-        if (in instanceof java.sql.Time) {
-          setTime(parameterIndex, (java.sql.Time) in);
+        if (in instanceof Time) {
+          setTime(parameterIndex, (Time) in);
         } else {
-          java.sql.Time tmpt;
+          Time tmpt;
           if (in instanceof java.util.Date) {
-            tmpt = new java.sql.Time(((java.util.Date) in).getTime());
+            tmpt = new Time(((java.util.Date) in).getTime());
           } else if (in instanceof LocalTime) {
             setTime(parameterIndex, (LocalTime) in);
             break;
@@ -650,12 +673,12 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
       case Types.TIMESTAMP:
         if (in instanceof PGTimestamp) {
           setObject(parameterIndex, in);
-        } else if (in instanceof java.sql.Timestamp) {
-          setTimestamp(parameterIndex, (java.sql.Timestamp) in);
+        } else if (in instanceof Timestamp) {
+          setTimestamp(parameterIndex, (Timestamp) in);
         } else {
-          java.sql.Timestamp tmpts;
+          Timestamp tmpts;
           if (in instanceof java.util.Date) {
-            tmpts = new java.sql.Timestamp(((java.util.Date) in).getTime());
+            tmpts = new Timestamp(((java.util.Date) in).getTime());
           } else if (in instanceof LocalDateTime) {
             setTimestamp(parameterIndex, (LocalDateTime) in);
             break;
@@ -914,7 +937,7 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
       if (in instanceof String) {
         rc = new BigDecimal((String) in);
       } else if (in instanceof BigDecimal) {
-        rc = ((BigDecimal) in);
+        rc = (BigDecimal) in;
       } else if (in instanceof BigInteger) {
         rc = new BigDecimal((BigInteger) in);
       } else if (in instanceof Long || in instanceof Integer || in instanceof Short
@@ -970,6 +993,7 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
         PSQLState.INVALID_PARAMETER_TYPE, cause);
   }
 
+  @Override
   public void setObject(/* @Positive */ int parameterIndex, /* @Nullable */ Object x,
       int targetSqlType) throws SQLException {
     setObject(parameterIndex, x, targetSqlType, -1);
@@ -978,6 +1002,7 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
   /*
    * This stores an Object into a parameter.
    */
+  @Override
   public void setObject(/* @Positive */ int parameterIndex, /* @Nullable */ Object x) throws SQLException {
     checkClosed();
     if (x == null) {
@@ -1004,8 +1029,8 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
       setBytes(parameterIndex, (byte[]) x);
     } else if (x instanceof ByteStreamWriter) {
       setByteStreamWriter(parameterIndex, (ByteStreamWriter) x);
-    } else if (x instanceof java.sql.Date) {
-      setDate(parameterIndex, (java.sql.Date) x);
+    } else if (x instanceof Date) {
+      setDate(parameterIndex, (Date) x);
     } else if (x instanceof Time) {
       setTime(parameterIndex, (Time) x);
     } else if (x instanceof Timestamp) {
@@ -1059,6 +1084,7 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
    *
    * @return SQL statement with the current template values substituted
    */
+  @Override
   public String toString() {
     if (preparedQuery == null) {
       return super.toString();
@@ -1102,8 +1128,8 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
 
   @Override
   public boolean isUseServerPrepare() {
-    return (preparedQuery != null && mPrepareThreshold != 0
-        && preparedQuery.getExecuteCount() + 1 >= mPrepareThreshold);
+    return preparedQuery != null && mPrepareThreshold != 0
+        && preparedQuery.getExecuteCount() + 1 >= mPrepareThreshold;
   }
 
   @Override
@@ -1120,7 +1146,7 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     checkClosed();
     ArrayList<Query> batchStatements = this.batchStatements;
     if (batchStatements == null) {
-      this.batchStatements = batchStatements = new ArrayList<Query>();
+      this.batchStatements = batchStatements = new ArrayList<>();
     }
     ArrayList</* @Nullable */ ParameterList> batchParameters = this.batchParameters;
     if (batchParameters == null) {
@@ -1134,6 +1160,7 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     }
   }
 
+  @Override
   public /* @Nullable */ ResultSetMetaData getMetaData() throws SQLException {
     checkClosed();
     ResultSet rs = getResultSet();
@@ -1162,7 +1189,8 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     return null;
   }
 
-  public void setArray(int i, java.sql./* @Nullable */ Array x) throws SQLException {
+  @Override
+  public void setArray(int i, /* @Nullable */ Array x) throws SQLException {
     checkClosed();
 
     if (null == x) {
@@ -1198,7 +1226,7 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     LargeObjectManager lom = connection.getLargeObjectAPI();
     long oid = lom.createLO();
     LargeObject lob = lom.open(oid);
-    try (OutputStream outputStream = lob.getOutputStream();) {
+    try (OutputStream outputStream = lob.getOutputStream()) {
       // The actual buffer size does not matter much, see benchmarks
       // https://github.com/pgjdbc/pgjdbc/pull/3044#issuecomment-1838057929
       // BlobOutputStream would gradually increase the buffer, so it will level the number of
@@ -1219,6 +1247,7 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     return oid;
   }
 
+  @Override
   public void setBlob(/* @Positive */ int i, /* @Nullable */ Blob x) throws SQLException {
     checkClosed();
 
@@ -1257,7 +1286,8 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     }
   }
 
-  public void setCharacterStream(/* @Positive */ int i, java.io./* @Nullable */ Reader x,
+  @Override
+  public void setCharacterStream(/* @Positive */ int i, /* @Nullable */ Reader x,
       /* @NonNegative */ int length) throws SQLException {
     checkClosed();
 
@@ -1317,6 +1347,7 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     setLong(i, oid);
   }
 
+  @Override
   public void setNull(/* @Positive */ int parameterIndex, int t,
       /* @Nullable */ String typeName) throws SQLException {
     if (typeName == null) {
@@ -1332,12 +1363,14 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     preparedParameters.setNull(parameterIndex, oid);
   }
 
+  @Override
   public void setRef(/* @Positive */ int i, /* @Nullable */ Ref x) throws SQLException {
     throw Driver.notImplemented(this.getClass(), "setRef(int,Ref)");
   }
 
-  public void setDate(/* @Positive */ int i, java.sql./* @Nullable */ Date d,
-      java.util./* @Nullable */ Calendar cal) throws SQLException {
+  @Override
+  public void setDate(/* @Positive */ int i, /* @Nullable */ Date d,
+      /* @Nullable */ Calendar cal) throws SQLException {
     checkClosed();
 
     if (d == null) {
@@ -1378,8 +1411,9 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     bindString(i, getTimestampUtils().toString(cal, d), Oid.UNSPECIFIED);
   }
 
+  @Override
   public void setTime(/* @Positive */ int i, /* @Nullable */ Time t,
-      java.util./* @Nullable */ Calendar cal) throws SQLException {
+      /* @Nullable */ Calendar cal) throws SQLException {
     checkClosed();
 
     if (t == null) {
@@ -1406,8 +1440,9 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     bindString(i, getTimestampUtils().toString(cal, t), oid);
   }
 
+  @Override
   public void setTimestamp(/* @Positive */ int i, /* @Nullable */ Timestamp t,
-      java.util./* @Nullable */ Calendar cal) throws SQLException {
+      /* @Nullable */ Calendar cal) throws SQLException {
     checkClosed();
 
     if (t == null) {
@@ -1495,53 +1530,62 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     return new PgParameterMetaData(conn, oids);
   }
 
+  @Override
   public void setObject(/* @Positive */ int parameterIndex, /* @Nullable */ Object x,
-      java.sql.SQLType targetSqlType,
+      SQLType targetSqlType,
       int scaleOrLength) throws SQLException {
     throw Driver.notImplemented(this.getClass(), "setObject");
   }
 
+  @Override
   public void setObject(/* @Positive */ int parameterIndex, /* @Nullable */ Object x,
-      java.sql.SQLType targetSqlType)
+      SQLType targetSqlType)
       throws SQLException {
     throw Driver.notImplemented(this.getClass(), "setObject");
   }
 
+  @Override
   public void setRowId(/* @Positive */ int parameterIndex, /* @Nullable */ RowId x) throws SQLException {
     throw Driver.notImplemented(this.getClass(), "setRowId(int, RowId)");
   }
 
+  @Override
   public void setNString(/* @Positive */ int parameterIndex, /* @Nullable */ String value) throws SQLException {
     throw Driver.notImplemented(this.getClass(), "setNString(int, String)");
   }
 
+  @Override
   public void setNCharacterStream(/* @Positive */ int parameterIndex, /* @Nullable */ Reader value, long length)
       throws SQLException {
     throw Driver.notImplemented(this.getClass(), "setNCharacterStream(int, Reader, long)");
   }
 
+  @Override
   public void setNCharacterStream(/* @Positive */ int parameterIndex,
       /* @Nullable */ Reader value) throws SQLException {
     throw Driver.notImplemented(this.getClass(), "setNCharacterStream(int, Reader)");
   }
 
+  @Override
   public void setCharacterStream(/* @Positive */ int parameterIndex,
       /* @Nullable */ Reader value, /* @NonNegative */ long length)
       throws SQLException {
     throw Driver.notImplemented(this.getClass(), "setCharacterStream(int, Reader, long)");
   }
 
+  @Override
   public void setCharacterStream(/* @Positive */ int parameterIndex,
       /* @Nullable */ Reader value) throws SQLException {
     if (connection.getPreferQueryMode() == PreferQueryMode.SIMPLE) {
-      String s = (value != null) ? readerToString(value, Integer.MAX_VALUE) : null;
+      String s = value != null ? readerToString(value, Integer.MAX_VALUE) : null;
       setString(parameterIndex, s);
       return;
     }
-    InputStream is = (value != null) ? new ReaderInputStream(value) : null;
+    InputStream is = value != null ? new ReaderInputStream(value) : null;
     setObject(parameterIndex, is, Types.LONGVARCHAR);
   }
 
+  @Override
   public void setBinaryStream(/* @Positive */ int parameterIndex, /* @Nullable */ InputStream value,
       /* @NonNegative */ /* @IntRange(from = 0, to = Integer.MAX_VALUE) */ long length)
       throws SQLException {
@@ -1557,6 +1601,7 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     }
   }
 
+  @Override
   public void setBinaryStream(/* @Positive */ int parameterIndex,
       /* @Nullable */ InputStream value) throws SQLException {
     if (value == null) {
@@ -1566,32 +1611,38 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     }
   }
 
+  @Override
   public void setAsciiStream(/* @Positive */ int parameterIndex,
       /* @Nullable */ InputStream value, /* @NonNegative */ long length)
       throws SQLException {
     throw Driver.notImplemented(this.getClass(), "setAsciiStream(int, InputStream, long)");
   }
 
+  @Override
   public void setAsciiStream(/* @Positive */ int parameterIndex,
       /* @Nullable */ InputStream value) throws SQLException {
     throw Driver.notImplemented(this.getClass(), "setAsciiStream(int, InputStream)");
   }
 
+  @Override
   public void setNClob(/* @Positive */ int parameterIndex,
       /* @Nullable */ NClob value) throws SQLException {
     throw Driver.notImplemented(this.getClass(), "setNClob(int, NClob)");
   }
 
+  @Override
   public void setClob(/* @Positive */ int parameterIndex,
       /* @Nullable */ Reader reader, /* @NonNegative */ long length) throws SQLException {
     throw Driver.notImplemented(this.getClass(), "setClob(int, Reader, long)");
   }
 
+  @Override
   public void setClob(/* @Positive */ int parameterIndex,
       /* @Nullable */ Reader reader) throws SQLException {
     throw Driver.notImplemented(this.getClass(), "setClob(int, Reader)");
   }
 
+  @Override
   public void setBlob(/* @Positive */ int parameterIndex,
       /* @Nullable */ InputStream inputStream, /* @NonNegative */ long length)
       throws SQLException {
@@ -1612,6 +1663,7 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     setLong(parameterIndex, oid);
   }
 
+  @Override
   public void setBlob(/* @Positive */ int parameterIndex,
       /* @Nullable */ InputStream inputStream) throws SQLException {
     checkClosed();
@@ -1625,16 +1677,19 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     setLong(parameterIndex, oid);
   }
 
+  @Override
   public void setNClob(/* @Positive */ int parameterIndex,
       /* @Nullable */ Reader reader, /* @NonNegative */ long length) throws SQLException {
     throw Driver.notImplemented(this.getClass(), "setNClob(int, Reader, long)");
   }
 
+  @Override
   public void setNClob(/* @Positive */ int parameterIndex,
       /* @Nullable */ Reader reader) throws SQLException {
     throw Driver.notImplemented(this.getClass(), "setNClob(int, Reader)");
   }
 
+  @Override
   public void setSQLXML(/* @Positive */ int parameterIndex,
       /* @Nullable */ SQLXML xmlObject) throws SQLException {
     checkClosed();
@@ -1657,7 +1712,8 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     }
   }
 
-  public void setURL(/* @Positive */ int parameterIndex, java.net./* @Nullable */ URL x) throws SQLException {
+  @Override
+  public void setURL(/* @Positive */ int parameterIndex, /* @Nullable */ URL x) throws SQLException {
     throw Driver.notImplemented(this.getClass(), "setURL(int,URL)");
   }
 
@@ -1691,6 +1747,7 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     return sharedCalendar;
   }
 
+  @Override
   public ParameterMetaData getParameterMetaData() throws SQLException {
     int flags = QueryExecutor.QUERY_ONESHOT | QueryExecutor.QUERY_DESCRIBE_ONLY
         | QueryExecutor.QUERY_SUPPRESS_BEGIN;
@@ -1724,7 +1781,7 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     final int fullValueBlocksCount = unprocessedBatchCount / maxValueBlocks;
     final int partialValueBlocksCount = Integer.bitCount(unprocessedBatchCount % maxValueBlocks);
     final int count = fullValueBlocksCount + partialValueBlocksCount;
-    ArrayList<Query> newBatchStatements = new ArrayList<Query>(count);
+    ArrayList<Query> newBatchStatements = new ArrayList<>(count);
     ArrayList</* @Nullable */ ParameterList> newBatchParameters =
         new ArrayList</* @Nullable */ ParameterList>(count);
     int offset = 0;
