@@ -54,13 +54,13 @@ public class PgStatement implements Statement, BaseStatement {
   private boolean forceBinaryTransfers = DEFAULT_FORCE_BINARY_TRANSFERS;
 
   protected final ResourceLock lock = new ResourceLock();
-  protected /* @Nullable */ ArrayList<Query> batchStatements = null;
-  protected /* @Nullable */ ArrayList</* @Nullable */ ParameterList> batchParameters = null;
+  protected /* @Nullable */ ArrayList<Query> batchStatements;
+  protected /* @Nullable */ ArrayList</* @Nullable */ ParameterList> batchParameters;
   protected final int resultsettype; // the resultset type to return (ResultSet.TYPE_xxx)
   protected final int concurrency; // is it updateable or not? (ResultSet.CONCUR_xxx)
   private final int rsHoldability;
   private boolean poolable;
-  private boolean closeOnCompletion = false;
+  private boolean closeOnCompletion;
   protected int fetchdirection = ResultSet.FETCH_FORWARD;
   // fetch direction hint (currently ignored)
 
@@ -71,10 +71,13 @@ public class PgStatement implements Statement, BaseStatement {
    * cancelTask was created. Note: the field must be set/get/compareAndSet via
    * {@link #CANCEL_TIMER_UPDATER} as per {@link AtomicReferenceFieldUpdater} javadoc.
    */
-  private volatile /* @Nullable */ TimerTask cancelTimerTask = null;
+  private volatile /* @Nullable */ TimerTask cancelTimerTask;
+
+  @SuppressWarnings("RedundantCast")
+  // Cast is needed for checkerframework to accept the code
   private static final AtomicReferenceFieldUpdater<PgStatement, /* @Nullable */ TimerTask> CANCEL_TIMER_UPDATER =
-      AtomicReferenceFieldUpdater.<PgStatement, /* @Nullable */ TimerTask>newUpdater(
-          PgStatement.class, TimerTask.class, "cancelTimerTask");
+      AtomicReferenceFieldUpdater.newUpdater(
+          PgStatement.class, (Class</* @Nullable */ TimerTask>) TimerTask.class, "cancelTimerTask");
 
   /**
    * Protects statement from out-of-order cancels. It protects from both
@@ -97,13 +100,13 @@ public class PgStatement implements Statement, BaseStatement {
    * Does the caller of execute/executeUpdate want generated keys for this execution? This is set by
    * Statement methods that have generated keys arguments and cleared after execution is complete.
    */
-  protected boolean wantsGeneratedKeysOnce = false;
+  protected boolean wantsGeneratedKeysOnce;
 
   /**
    * Was this PreparedStatement created to return generated keys for every execution? This is set at
    * creation time and never cleared by execution.
    */
-  public boolean wantsGeneratedKeysAlways = false;
+  public boolean wantsGeneratedKeysAlways;
 
   // The connection who created us
   protected final PgConnection connection;
@@ -111,45 +114,45 @@ public class PgStatement implements Statement, BaseStatement {
   /**
    * The warnings chain.
    */
-  protected volatile /* @Nullable */ PSQLWarningWrapper warnings = null;
+  protected volatile /* @Nullable */ PSQLWarningWrapper warnings;
 
   /**
    * Maximum number of rows to return, 0 = unlimited.
    */
-  protected int maxrows = 0;
+  protected int maxrows;
 
   /**
    * Number of rows to get in a batch.
    */
-  protected int fetchSize = 0;
+  protected int fetchSize;
 
   /**
    * Timeout (in milliseconds) for a query.
    */
-  protected long timeout = 0;
+  protected long timeout;
 
   protected boolean replaceProcessingEnabled = true;
 
   /**
    * The current results.
    */
-  protected /* @Nullable */ ResultWrapper result = null;
+  protected /* @Nullable */ ResultWrapper result;
 
   /**
    * The first unclosed result.
    */
-  protected /* @Nullable */ /* @GuardedBy("<self>") */ ResultWrapper firstUnclosedResult = null;
+  protected /* @Nullable */ /* @GuardedBy("<self>") */ ResultWrapper firstUnclosedResult;
 
   /**
    * Results returned by a statement that wants generated keys.
    */
-  protected /* @Nullable */ ResultWrapper generatedKeys = null;
+  protected /* @Nullable */ ResultWrapper generatedKeys;
 
   protected int mPrepareThreshold; // Reuse threshold to enable use of PREPARE
 
-  protected int maxFieldSize = 0;
+  protected int maxFieldSize;
 
-  protected boolean adaptiveFetch = false;
+  protected boolean adaptiveFetch;
 
   private /* @Nullable */ TimestampUtils timestampUtils; // our own Object because it's not thread safe
 
@@ -166,6 +169,7 @@ public class PgStatement implements Statement, BaseStatement {
     this.rsHoldability = rsHoldability;
   }
 
+  @Override
   @SuppressWarnings("method.invocation")
   public ResultSet createResultSet(/* @Nullable */ Query originalQuery, Field[] fields, List<Tuple> tuples,
       /* @Nullable */ ResultCursor cursor) throws SQLException {
@@ -185,6 +189,7 @@ public class PgStatement implements Statement, BaseStatement {
     return null;
   }
 
+  @Override
   public /* @NonNegative */ int getFetchSize() {
     return fetchSize;
   }
@@ -327,6 +332,7 @@ public class PgStatement implements Statement, BaseStatement {
     return res;
   }
 
+  @Override
   public boolean executeWithFlags(CachedQuery simpleQuery, int flags) throws SQLException {
     checkClosed();
     if (connection.getPreferQueryMode().compareTo(PreferQueryMode.EXTENDED) < 0) {
@@ -335,10 +341,11 @@ public class PgStatement implements Statement, BaseStatement {
     execute(simpleQuery, null, flags);
     try (ResourceLock ignore = lock.obtain()) {
       checkClosed();
-      return (result != null && result.getResultSet() != null);
+      return result != null && result.getResultSet() != null;
     }
   }
 
+  @Override
   public boolean executeWithFlags(int flags) throws SQLException {
     checkClosed();
     throw new PSQLException(GT.tr("Can''t use executeWithFlags(int) on a Statement."),
@@ -400,11 +407,8 @@ public class PgStatement implements Statement, BaseStatement {
       return true;
     }
     cachedQuery.increaseExecuteCount();
-    if ((mPrepareThreshold == 0 || cachedQuery.getExecuteCount() < mPrepareThreshold)
-        && !getForceBinaryTransfer()) {
-      return true;
-    }
-    return false;
+    return (mPrepareThreshold == 0 || cachedQuery.getExecuteCount() < mPrepareThreshold)
+        && !getForceBinaryTransfer();
   }
 
   protected final void execute(CachedQuery cachedQuery,
@@ -517,12 +521,13 @@ public class PgStatement implements Statement, BaseStatement {
     }
   }
 
+  @Override
   public void setCursorName(String name) throws SQLException {
     checkClosed();
     // No-op.
   }
 
-  private volatile int isClosed = 0;
+  private volatile int isClosed;
   private static final AtomicIntegerFieldUpdater<PgStatement> IS_CLOSED_UPDATER =
       AtomicIntegerFieldUpdater.newUpdater(
           PgStatement.class, "isClosed");
@@ -540,15 +545,18 @@ public class PgStatement implements Statement, BaseStatement {
     }
   }
 
+  @Override
   public boolean getMoreResults() throws SQLException {
     return getMoreResults(CLOSE_ALL_RESULTS);
   }
 
+  @Override
   public int getMaxRows() throws SQLException {
     checkClosed();
     return maxrows;
   }
 
+  @Override
   public void setMaxRows(int max) throws SQLException {
     checkClosed();
     if (max < 0) {
@@ -559,11 +567,13 @@ public class PgStatement implements Statement, BaseStatement {
     maxrows = max;
   }
 
+  @Override
   public void setEscapeProcessing(boolean enable) throws SQLException {
     checkClosed();
     replaceProcessingEnabled = enable;
   }
 
+  @Override
   public int getQueryTimeout() throws SQLException {
     checkClosed();
     long seconds = timeout / 1000;
@@ -573,6 +583,7 @@ public class PgStatement implements Statement, BaseStatement {
     return (int) seconds;
   }
 
+  @Override
   public void setQueryTimeout(int seconds) throws SQLException {
     setQueryTimeoutMs(seconds * 1000L);
   }
@@ -624,6 +635,7 @@ public class PgStatement implements Statement, BaseStatement {
     }
   }
 
+  @Override
   public /* @Nullable */ SQLWarning getWarnings() throws SQLException {
     checkClosed();
     //copy reference to avoid NPE from concurrent modification of this.warnings
@@ -654,10 +666,12 @@ public class PgStatement implements Statement, BaseStatement {
    * Therefore you should hold a reference to the tail of the previous warning chain
    * and verify if its {@link SQLWarning#getNextWarning()} value is holds any new value.</p>
    */
+  @Override
   public void clearWarnings() throws SQLException {
     warnings = null;
   }
 
+  @Override
   public /* @Nullable */ ResultSet getResultSet() throws SQLException {
     try (ResourceLock ignore = lock.obtain()) {
       checkClosed();
@@ -676,6 +690,7 @@ public class PgStatement implements Statement, BaseStatement {
    *
    * {@inheritDoc}
    */
+  @Override
   public final void close() throws SQLException {
     // closing an already closed Statement is a no-op.
     if (!IS_CLOSED_UPDATER.compareAndSet(this, 0, 1)) {
@@ -702,6 +717,7 @@ public class PgStatement implements Statement, BaseStatement {
    *
    */
 
+  @Override
   public long getLastOID() throws SQLException {
     try (ResourceLock ignore = lock.obtain()) {
       checkClosed();
@@ -755,7 +771,7 @@ public class PgStatement implements Statement, BaseStatement {
 
     ArrayList<Query> batchStatements = this.batchStatements;
     if (batchStatements == null) {
-      this.batchStatements = batchStatements = new ArrayList<Query>();
+      this.batchStatements = batchStatements = new ArrayList<>();
     }
     ArrayList</* @Nullable */ ParameterList> batchParameters = this.batchParameters;
     if (batchParameters == null) {
@@ -908,6 +924,7 @@ public class PgStatement implements Statement, BaseStatement {
     return handler;
   }
 
+  @Override
   public int[] executeBatch() throws SQLException {
     checkClosed();
     closeForNextExecution();
@@ -919,6 +936,7 @@ public class PgStatement implements Statement, BaseStatement {
     return internalExecuteBatch().getUpdateCount();
   }
 
+  @Override
   public void cancel() throws SQLException {
     if (statementState == StatementCancelState.IDLE) {
       return;
@@ -939,22 +957,27 @@ public class PgStatement implements Statement, BaseStatement {
     }
   }
 
+  @Override
   public Connection getConnection() throws SQLException {
     return connection;
   }
 
+  @Override
   public int getFetchDirection() {
     return fetchdirection;
   }
 
+  @Override
   public int getResultSetConcurrency() {
     return concurrency;
   }
 
+  @Override
   public int getResultSetType() {
     return resultsettype;
   }
 
+  @Override
   public void setFetchDirection(int direction) throws SQLException {
     switch (direction) {
       case ResultSet.FETCH_FORWARD:
@@ -968,6 +991,7 @@ public class PgStatement implements Statement, BaseStatement {
     }
   }
 
+  @Override
   public void setFetchSize(/* @NonNegative */ int rows) throws SQLException {
     checkClosed();
     if (rows < 0) {
@@ -1077,10 +1101,12 @@ public class PgStatement implements Statement, BaseStatement {
     }
   }
 
+  @Override
   public void setLargeMaxRows(long max) throws SQLException {
     throw Driver.notImplemented(this.getClass(), "setLargeMaxRows");
   }
 
+  @Override
   public long getLargeMaxRows() throws SQLException {
     throw Driver.notImplemented(this.getClass(), "getLargeMaxRows");
   }
@@ -1140,24 +1166,29 @@ public class PgStatement implements Statement, BaseStatement {
     }
   }
 
+  @Override
   public boolean isClosed() throws SQLException {
     return isClosed == 1;
   }
 
+  @Override
   public void setPoolable(boolean poolable) throws SQLException {
     checkClosed();
     this.poolable = poolable;
   }
 
+  @Override
   public boolean isPoolable() throws SQLException {
     checkClosed();
     return poolable;
   }
 
+  @Override
   public boolean isWrapperFor(Class<?> iface) throws SQLException {
     return iface.isAssignableFrom(getClass());
   }
 
+  @Override
   public <T> T unwrap(Class<T> iface) throws SQLException {
     if (iface.isAssignableFrom(getClass())) {
       return iface.cast(this);
@@ -1165,10 +1196,12 @@ public class PgStatement implements Statement, BaseStatement {
     throw new SQLException("Cannot unwrap to " + iface.getName());
   }
 
+  @Override
   public void closeOnCompletion() throws SQLException {
     closeOnCompletion = true;
   }
 
+  @Override
   public boolean isCloseOnCompletion() throws SQLException {
     return closeOnCompletion;
   }
@@ -1199,6 +1232,7 @@ public class PgStatement implements Statement, BaseStatement {
     }
   }
 
+  @Override
   public boolean getMoreResults(int current) throws SQLException {
     try (ResourceLock ignore = lock.obtain()) {
       checkClosed();
@@ -1220,21 +1254,23 @@ public class PgStatement implements Statement, BaseStatement {
       }
 
       // Done.
-      return (result != null && result.getResultSet() != null);
+      return result != null && result.getResultSet() != null;
     }
   }
 
+  @Override
   public ResultSet getGeneratedKeys() throws SQLException {
     try (ResourceLock ignore = lock.obtain()) {
       checkClosed();
       if (generatedKeys == null || generatedKeys.getResultSet() == null) {
-        return createDriverResultSet(new Field[0], new ArrayList<Tuple>());
+        return createDriverResultSet(new Field[0], new ArrayList<>());
       }
 
       return generatedKeys.getResultSet();
     }
   }
 
+  @Override
   public int executeUpdate(String sql, int autoGeneratedKeys) throws SQLException {
     if (autoGeneratedKeys == Statement.NO_GENERATED_KEYS) {
       return executeUpdate(sql);
@@ -1243,6 +1279,7 @@ public class PgStatement implements Statement, BaseStatement {
     return executeUpdate(sql, (String[]) null);
   }
 
+  @Override
   public int executeUpdate(String sql, int[] columnIndexes) throws SQLException {
     if (columnIndexes == null || columnIndexes.length == 0) {
       return executeUpdate(sql);
@@ -1252,6 +1289,7 @@ public class PgStatement implements Statement, BaseStatement {
         PSQLState.NOT_IMPLEMENTED);
   }
 
+  @Override
   public int executeUpdate(String sql, String /* @Nullable */ [] columnNames) throws SQLException {
     try (ResourceLock ignore = lock.obtain()) {
       if (columnNames != null && columnNames.length == 0) {
@@ -1266,6 +1304,7 @@ public class PgStatement implements Statement, BaseStatement {
     }
   }
 
+  @Override
   public boolean execute(String sql, int autoGeneratedKeys) throws SQLException {
     if (autoGeneratedKeys == Statement.NO_GENERATED_KEYS) {
       return execute(sql);
@@ -1273,6 +1312,7 @@ public class PgStatement implements Statement, BaseStatement {
     return execute(sql, (String[]) null);
   }
 
+  @Override
   public boolean execute(String sql, int /* @Nullable */ [] columnIndexes) throws SQLException {
     if (columnIndexes != null && columnIndexes.length == 0) {
       return execute(sql);
@@ -1282,6 +1322,7 @@ public class PgStatement implements Statement, BaseStatement {
         PSQLState.NOT_IMPLEMENTED);
   }
 
+  @Override
   public boolean execute(String sql, String /* @Nullable */ [] columnNames) throws SQLException {
     try (ResourceLock ignore = lock.obtain()) {
       if (columnNames != null && columnNames.length == 0) {
@@ -1293,10 +1334,12 @@ public class PgStatement implements Statement, BaseStatement {
     }
   }
 
+  @Override
   public int getResultSetHoldability() throws SQLException {
     return rsHoldability;
   }
 
+  @Override
   public ResultSet createDriverResultSet(Field[] fields, List<Tuple> tuples)
       throws SQLException {
     return createResultSet(null, fields, tuples, null);
@@ -1317,7 +1360,7 @@ public class PgStatement implements Statement, BaseStatement {
 
   protected TimestampUtils getTimestampUtils() {
     if (timestampUtils == null) {
-      timestampUtils = new TimestampUtils(! connection.getQueryExecutor().getIntegerDateTimes(), (Provider<TimeZone>) new QueryExecutorTimeZoneProvider(connection.getQueryExecutor()));
+      timestampUtils = new TimestampUtils(!connection.getQueryExecutor().getIntegerDateTimes(), (Provider<TimeZone>) new QueryExecutorTimeZoneProvider(connection.getQueryExecutor()));
     }
     return timestampUtils;
   }
