@@ -5,23 +5,16 @@
 
 package org.postgresql.core;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+
 import org.postgresql.util.PSQLException;
 
-import org.junit.Assert;
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.MethodSource;
 
 import java.util.Arrays;
 
-@RunWith(Parameterized.class)
 public class OidValueOfTest {
-  @Parameterized.Parameter(0)
-  public int expected;
-  @Parameterized.Parameter(1)
-  public String value;
-
-  @Parameterized.Parameters(name = "expected={0}, value={1}")
   public static Iterable<Object[]> data() {
     return Arrays.asList(new Object[][]{
         {25, "TEXT"},
@@ -31,8 +24,9 @@ public class OidValueOfTest {
     });
   }
 
-  @Test
-  public void run() throws PSQLException {
-    Assert.assertEquals(expected, Oid.valueOf(value));
+  @MethodSource("data")
+  @ParameterizedTest(name = "expected={0}, value={1}")
+  void run(int expected, String value) throws PSQLException {
+    assertEquals(expected, Oid.valueOf(value));
   }
 }
