@@ -61,7 +61,7 @@ public class PreparedStatementTest extends BaseTest4 {
 
   @Parameterized.Parameters(name = "binary = {0}")
   public static Iterable<Object[]> data() {
-    Collection<Object[]> ids = new ArrayList<Object[]>();
+    Collection<Object[]> ids = new ArrayList<>();
     for (BinaryMode binaryMode : BinaryMode.values()) {
       ids.add(new Object[]{binaryMode});
     }
@@ -318,7 +318,7 @@ public class PreparedStatementTest extends BaseTest4 {
     ResultSet rs = pstmt.executeQuery();
 
     assertTrue(rs.next());
-    assertEquals("ok",rs.getObject(1));
+    assertEquals("ok", rs.getObject(1));
 
     rs.close();
     pstmt.close();
@@ -359,7 +359,7 @@ public class PreparedStatementTest extends BaseTest4 {
 
     // Test with standard_conforming_strings turned off.
     stmt.execute("SET standard_conforming_strings TO off");
-    for (int i = 0; i < testStrings.length; ++i) {
+    for (int i = 0; i < testStrings.length; i++) {
       PreparedStatement pstmt = con.prepareStatement("SELECT '" + testStrings[i] + "'");
       ResultSet rs = pstmt.executeQuery();
       assertTrue(rs.next());
@@ -371,7 +371,7 @@ public class PreparedStatementTest extends BaseTest4 {
     // Test with standard_conforming_strings turned off...
     // ... using the escape string syntax (E'').
     stmt.execute("SET standard_conforming_strings TO on");
-    for (int i = 0; i < testStrings.length; ++i) {
+    for (int i = 0; i < testStrings.length; i++) {
       PreparedStatement pstmt = con.prepareStatement("SELECT E'" + testStrings[i] + "'");
       ResultSet rs = pstmt.executeQuery();
       assertTrue(rs.next());
@@ -380,7 +380,7 @@ public class PreparedStatementTest extends BaseTest4 {
       pstmt.close();
     }
     // ... using standard conforming input strings.
-    for (int i = 0; i < testStrings.length; ++i) {
+    for (int i = 0; i < testStrings.length; i++) {
       PreparedStatement pstmt = con.prepareStatement("SELECT '" + testStringsStdConf[i] + "'");
       ResultSet rs = pstmt.executeQuery();
       assertTrue(rs.next());
@@ -546,7 +546,7 @@ public class PreparedStatementTest extends BaseTest4 {
     values[3] = new BigDecimal("-" + minValueString);
 
     pstmt = con.prepareStatement("insert into numeric_tab values (?,?,?,?,?)");
-    for (int i = 1; i < 5 ; i++) {
+    for (int i = 1; i < 5; i++) {
       pstmt.setBigDecimal(i, values[i - 1]);
     }
 
@@ -557,7 +557,7 @@ public class PreparedStatementTest extends BaseTest4 {
     pstmt = con.prepareStatement("select * from numeric_tab");
     ResultSet rs = pstmt.executeQuery();
     assertTrue(rs.next());
-    for (int i = 1; i < 5 ; i++) {
+    for (int i = 1; i < 5; i++) {
       assertTrue(rs.getBigDecimal(i).compareTo(values[i - 1]) == 0);
     }
     rs.getDouble(5);
@@ -1010,9 +1010,9 @@ public class PreparedStatementTest extends BaseTest4 {
     assertNull("rs.getBigDecimal(scale=0)", rs.getBigDecimal(3, 0));
     assertTrue("rs.getBigDecimal after rs.getLong", rs.wasNull());
     assertEquals("maxInt as rs.getBigDecimal(scale=1)",
-        BigDecimal.valueOf(maxInt).setScale(1, BigDecimal.ROUND_HALF_EVEN), rs.getBigDecimal(1, 1));
+        BigDecimal.valueOf(maxInt).setScale(1, RoundingMode.HALF_EVEN), rs.getBigDecimal(1, 1));
     assertEquals("minInt as rs.getBigDecimal(scale=1)",
-        BigDecimal.valueOf(minInt).setScale(1, BigDecimal.ROUND_HALF_EVEN), rs.getBigDecimal(2, 1));
+        BigDecimal.valueOf(minInt).setScale(1, RoundingMode.HALF_EVEN), rs.getBigDecimal(2, 1));
     rs.getFloat(3);
     assertTrue(rs.wasNull());
     rs.close();
@@ -1464,7 +1464,7 @@ public class PreparedStatementTest extends BaseTest4 {
     try {
       Timestamp ts = new Timestamp(1474997614836L);
       // Since PreparedStatement isn't cached immediately, we need to some warm up
-      for (int i = 0; i < 3; ++i) {
+      for (int i = 0; i < 3; i++) {
         ResultSet rs;
 
         // Flip statement to use Oid.DATE
