@@ -5,12 +5,14 @@
 
 package org.postgresql.test.ssl;
 
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+
 import org.postgresql.ssl.LazyKeyManager;
 import org.postgresql.ssl.PKCS12KeyManager;
 import org.postgresql.test.TestUtil;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 import java.io.IOException;
 import java.security.PrivateKey;
@@ -22,32 +24,32 @@ import javax.security.auth.callback.PasswordCallback;
 import javax.security.auth.callback.UnsupportedCallbackException;
 import javax.security.auth.x500.X500Principal;
 
-public class LazyKeyManagerTest {
+class LazyKeyManagerTest {
 
   @Test
-  public void testLoadP12Key() throws Exception {
+  void loadP12Key() throws Exception {
     PKCS12KeyManager pkcs12KeyManager = new PKCS12KeyManager(
         TestUtil.getSslTestCertPath("goodclient.p12"),
         new TestCallbackHandler("sslpwd"));
     PrivateKey pk = pkcs12KeyManager.getPrivateKey("user");
-    Assert.assertNotNull(pk);
+    assertNotNull(pk);
     X509Certificate[] chain = pkcs12KeyManager.getCertificateChain("user");
-    Assert.assertNotNull(chain);
+    assertNotNull(chain);
   }
 
   @Test
-  public void testLoadKey() throws Exception {
+  void loadKey() throws Exception {
     LazyKeyManager lazyKeyManager = new LazyKeyManager(
         TestUtil.getSslTestCertPath("goodclient.crt"),
         TestUtil.getSslTestCertPath("goodclient.pk8"),
         new TestCallbackHandler("sslpwd"),
         true);
     PrivateKey pk = lazyKeyManager.getPrivateKey("user");
-    Assert.assertNotNull(pk);
+    assertNotNull(pk);
   }
 
   @Test
-  public void testChooseClientAlias() throws Exception {
+  void chooseClientAlias() throws Exception {
     LazyKeyManager lazyKeyManager = new LazyKeyManager(
         TestUtil.getSslTestCertPath("goodclient.crt"),
         TestUtil.getSslTestCertPath("goodclient.pk8"),
@@ -57,25 +59,25 @@ public class LazyKeyManagerTest {
     X500Principal[] issuers = new X500Principal[]{testPrincipal};
 
     String validKeyType = lazyKeyManager.chooseClientAlias(new String[]{"RSA"}, issuers, null);
-    Assert.assertNotNull(validKeyType);
+    assertNotNull(validKeyType);
 
     String ignoresCase = lazyKeyManager.chooseClientAlias(new String[]{"rsa"}, issuers, null);
-    Assert.assertNotNull(ignoresCase);
+    assertNotNull(ignoresCase);
 
     String invalidKeyType = lazyKeyManager.chooseClientAlias(new String[]{"EC"}, issuers, null);
-    Assert.assertNull(invalidKeyType);
+    assertNull(invalidKeyType);
 
-    String containsValidKeyType = lazyKeyManager.chooseClientAlias(new String[]{"EC","RSA"}, issuers, null);
-    Assert.assertNotNull(containsValidKeyType);
+    String containsValidKeyType = lazyKeyManager.chooseClientAlias(new String[]{"EC", "RSA"}, issuers, null);
+    assertNotNull(containsValidKeyType);
 
     String ignoresBlank = lazyKeyManager.chooseClientAlias(new String[]{}, issuers, null);
-    Assert.assertNotNull(ignoresBlank);
+    assertNotNull(ignoresBlank);
   }
 
   public static class TestCallbackHandler implements CallbackHandler {
     char [] password;
 
-    public TestCallbackHandler(String password) {
+    TestCallbackHandler(String password) {
       if (password != null) {
         this.password = password.toCharArray();
       }
