@@ -5,26 +5,32 @@
 
 package org.postgresql.test.ssl;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.fail;
+
 import org.postgresql.test.TestUtil;
 
 // import org.checkerframework.checker.nullness.qual.Nullable;
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 
 import java.io.BufferedReader;
 import java.io.FileInputStream;
+import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.io.InputStreamReader;
+import java.security.GeneralSecurityException;
 import java.sql.Connection;
 import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.sql.Statement;
 import java.util.Properties;
 
+import javax.net.ssl.SSLHandshakeException;
+
 public class SingleCertValidatingFactoryTest {
-  @BeforeClass
-  public static void setUp() {
+  @BeforeAll
+  static void setUp() {
     TestUtil.assumeSslTestsEnabled();
   }
 
@@ -79,13 +85,13 @@ public class SingleCertValidatingFactoryTest {
       // Basic SELECT test:
       ResultSet rs = stmt.executeQuery("SELECT 1");
       rs.next();
-      Assert.assertEquals(1, rs.getInt(1));
+      assertEquals(1, rs.getInt(1));
       rs.close();
       // Verify SSL usage is as expected:
       rs = stmt.executeQuery("SELECT ssl_is_used()");
       rs.next();
       boolean sslActual = rs.getBoolean(1);
-      Assert.assertEquals(sslExpected, sslActual);
+      assertEquals(sslExpected, sslActual);
       stmt.close();
     } catch (Exception e) {
       if (matchesExpected(e, expectedThrowable)) {
@@ -103,7 +109,7 @@ public class SingleCertValidatingFactoryTest {
     }
 
     if (expectedThrowable != null) {
-      Assert.fail("Expected exception " + expectedThrowable.getName() + " but it did not occur.");
+      fail("Expected exception " + expectedThrowable.getName() + " but it did not occur.");
     }
   }
 
@@ -112,11 +118,11 @@ public class SingleCertValidatingFactoryTest {
    * it. This connection attempt should *fail* as the client should reject the server.
    */
   @Test
-  public void connectSSLWithValidationNoCert() throws SQLException {
+  void connectSSLWithValidationNoCert() throws SQLException {
     Properties info = new Properties();
     info.setProperty("ssl", "true");
     info.setProperty("sslfactory", "org.postgresql.ssl.DefaultJavaSSLFactory");
-    testConnect(info, true, javax.net.ssl.SSLHandshakeException.class);
+    testConnect(info, true, SSLHandshakeException.class);
   }
 
   /**
@@ -131,30 +137,30 @@ public class SingleCertValidatingFactoryTest {
    * certificate does not match.</p>
    */
   @Test
-  public void connectSSLWithValidationWrongCert() throws SQLException, IOException {
+  void connectSSLWithValidationWrongCert() throws SQLException, IOException {
     Properties info = new Properties();
     info.setProperty("ssl", "true");
     info.setProperty("sslfactory", "org.postgresql.ssl.SingleCertValidatingFactory");
     info.setProperty("sslfactoryarg", "file:" + badServerCertPath);
-    testConnect(info, true, javax.net.ssl.SSLHandshakeException.class);
+    testConnect(info, true, SSLHandshakeException.class);
   }
 
   @Test
-  public void fileCertInvalid() throws SQLException, IOException {
+  void fileCertInvalid() throws SQLException, IOException {
     Properties info = new Properties();
     info.setProperty("ssl", "true");
     info.setProperty("sslfactory", "org.postgresql.ssl.SingleCertValidatingFactory");
     info.setProperty("sslfactoryarg", "file:foo/bar/baz");
-    testConnect(info, true, java.io.FileNotFoundException.class);
+    testConnect(info, true, FileNotFoundException.class);
   }
 
   @Test
-  public void stringCertInvalid() throws SQLException, IOException {
+  void stringCertInvalid() throws SQLException, IOException {
     Properties info = new Properties();
     info.setProperty("ssl", "true");
     info.setProperty("sslfactory", "org.postgresql.ssl.SingleCertValidatingFactory");
     info.setProperty("sslfactoryarg", "foobar!");
-    testConnect(info, true, java.security.GeneralSecurityException.class);
+    testConnect(info, true, GeneralSecurityException.class);
   }
 
   /**
@@ -163,7 +169,7 @@ public class SingleCertValidatingFactoryTest {
    * certificate from a local file.
    */
   @Test
-  public void connectSSLWithValidationProperCertFile() throws SQLException, IOException {
+  void connectSSLWithValidationProperCertFile() throws SQLException, IOException {
     Properties info = new Properties();
     info.setProperty("ssl", "true");
     info.setProperty("sslfactory", "org.postgresql.ssl.SingleCertValidatingFactory");
@@ -177,7 +183,7 @@ public class SingleCertValidatingFactoryTest {
    * ----- ... etc").
    */
   @Test
-  public void connectSSLWithValidationProperCertString() throws SQLException, IOException {
+  void connectSSLWithValidationProperCertString() throws SQLException, IOException {
     Properties info = new Properties();
     info.setProperty("ssl", "true");
     info.setProperty("sslfactory", "org.postgresql.ssl.SingleCertValidatingFactory");
@@ -190,7 +196,7 @@ public class SingleCertValidatingFactoryTest {
    * shared certificate. The certificate is specified as a system property.
    */
   @Test
-  public void connectSSLWithValidationProperCertSysProp() throws SQLException, IOException {
+  void connectSSLWithValidationProperCertSysProp() throws SQLException, IOException {
     // System property name we're using for the SSL cert. This can be anything.
     String sysPropName = "org.postgresql.jdbc.test.sslcert";
 
@@ -218,7 +224,7 @@ public class SingleCertValidatingFactoryTest {
    * <p>Here's one way to do it: $ DATASOURCE_SSL_CERT=$(cat certdir/goodroot.crt) ant clean test</p>
    */
   @Test
-  public void connectSSLWithValidationProperCertEnvVar() throws SQLException, IOException {
+  void connectSSLWithValidationProperCertEnvVar() throws SQLException, IOException {
     String envVarName = "DATASOURCE_SSL_CERT";
     if (System.getenv(envVarName) == null) {
       System.out.println(
@@ -238,7 +244,7 @@ public class SingleCertValidatingFactoryTest {
    * having it set. This tests whether the proper exception is thrown.
    */
   @Test
-  public void connectSSLWithValidationMissingSysProp() throws SQLException, IOException {
+  void connectSSLWithValidationMissingSysProp() throws SQLException, IOException {
     // System property name we're using for the SSL cert. This can be anything.
     String sysPropName = "org.postgresql.jdbc.test.sslcert";
 
@@ -249,7 +255,7 @@ public class SingleCertValidatingFactoryTest {
       info.setProperty("ssl", "true");
       info.setProperty("sslfactory", "org.postgresql.ssl.SingleCertValidatingFactory");
       info.setProperty("sslfactoryarg", "sys:" + sysPropName);
-      testConnect(info, true, java.security.GeneralSecurityException.class);
+      testConnect(info, true, GeneralSecurityException.class);
     } finally {
       // Clear it out when we're done:
       System.setProperty(sysPropName, "");
@@ -261,7 +267,7 @@ public class SingleCertValidatingFactoryTest {
    * having it set. This tests whether the proper exception is thrown.
    */
   @Test
-  public void connectSSLWithValidationMissingEnvVar() throws SQLException, IOException {
+  void connectSSLWithValidationMissingEnvVar() throws SQLException, IOException {
     // Use an environment variable that does *not* exist:
     String envVarName = "MISSING_DATASOURCE_SSL_CERT";
     if (System.getenv(envVarName) != null) {
@@ -274,7 +280,7 @@ public class SingleCertValidatingFactoryTest {
     info.setProperty("ssl", "true");
     info.setProperty("sslfactory", "org.postgresql.ssl.SingleCertValidatingFactory");
     info.setProperty("sslfactoryarg", "env:" + envVarName);
-    testConnect(info, true, java.security.GeneralSecurityException.class);
+    testConnect(info, true, GeneralSecurityException.class);
   }
 
   ///////////////////////////////////////////////////////////////////
