@@ -5,28 +5,29 @@
 
 package org.postgresql.test.xa;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
-import static org.junit.Assume.assumeTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
+import static org.junit.jupiter.api.Assumptions.assumeTrue;
 
 import org.postgresql.test.TestUtil;
-import org.postgresql.test.XaTests;
+import org.postgresql.test.annotations.tags.Xa;
 import org.postgresql.test.jdbc2.optional.BaseDataSourceTest;
 import org.postgresql.xa.PGXADataSource;
 
 // import org.checkerframework.checker.nullness.qual.Nullable;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.Test;
-import org.junit.experimental.categories.Category;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import java.sql.Connection;
 import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.sql.Statement;
+import java.sql.Timestamp;
 import java.util.Arrays;
 import java.util.Random;
 
@@ -36,7 +37,7 @@ import javax.transaction.xa.XAException;
 import javax.transaction.xa.XAResource;
 import javax.transaction.xa.Xid;
 
-@Category(XaTests.class)
+@Xa
 public class XADataSourceTest {
 
   private XADataSource xaDs;
@@ -53,15 +54,15 @@ public class XADataSourceTest {
     BaseDataSourceTest.setupDataSource((PGXADataSource) xaDs);
   }
 
-  @BeforeClass
-  public static void beforeClass() throws Exception {
-    try (Connection con = TestUtil.openDB();) {
-      assumeTrue("max_prepared_transactions should be non-zero for XA tests", isPreparedTransactionEnabled(con));
+  @BeforeAll
+  static void beforeClass() throws Exception {
+    try (Connection con = TestUtil.openDB()) {
+      assumeTrue(isPreparedTransactionEnabled(con), "max_prepared_transactions should be non-zero for XA tests");
     }
   }
 
-  @Before
-  public void setUp() throws Exception {
+  @BeforeEach
+  void setUp() throws Exception {
     dbConn = TestUtil.openDB();
 
     // Check if we're operating as a superuser; some tests require it.
@@ -93,8 +94,8 @@ public class XADataSourceTest {
     return mpt > 0;
   }
 
-  @After
-  public void tearDown() throws SQLException {
+  @AfterEach
+  void tearDown() throws SQLException {
     try {
       xaconn.close();
     } catch (Exception ignored) {
@@ -119,8 +120,8 @@ public class XADataSourceTest {
       Statement st2 = dbConn.createStatement();
       while (rs.next()) {
         // TODO: This should really use org.junit.Assume once we move to JUnit 4
-        assertTrue("Only prepared xacts owned by current user may be present in db",
-            rs.getBoolean(2));
+        assertTrue(rs.getBoolean(2),
+            "Only prepared xacts owned by current user may be present in db");
         st2.executeUpdate("ROLLBACK PREPARED '" + rs.getString(1) + "'");
       }
       st2.close();
@@ -174,11 +175,7 @@ public class XADataSourceTest {
       if (!Arrays.equals(other.getBranchQualifier(), this.getBranchQualifier())) {
         return false;
       }
-      if (!Arrays.equals(other.getGlobalTransactionId(), this.getGlobalTransactionId())) {
-        return false;
-      }
-
-      return true;
+      return Arrays.equals(other.getGlobalTransactionId(), this.getGlobalTransactionId());
     }
 
     @Override
@@ -197,14 +194,14 @@ public class XADataSourceTest {
    * PGXAConnection.getConnection().
    */
   @Test
-  public void testWrapperEquals() throws Exception {
-    assertTrue("Wrappers should be equal", conn.equals(conn));
-    assertFalse("Wrapper should be unequal to null", conn.equals(null));
-    assertFalse("Wrapper should be unequal to unrelated object", conn.equals("dummy string object"));
+  void wrapperEquals() throws Exception {
+    assertEquals(conn, conn, "Wrappers should be equal");
+    assertNotEquals(null, conn, "Wrapper should be unequal to null");
+    assertNotEquals("dummy string object", conn, "Wrapper should be unequal to unrelated object");
   }
 
   @Test
-  public void testOnePhase() throws Exception {
+  void onePhase() throws Exception {
     Xid xid = new CustomXid(1);
     xaRes.start(xid, XAResource.TMNOFLAGS);
     conn.createStatement().executeQuery("SELECT * FROM testxa1");
@@ -213,7 +210,7 @@ public class XADataSourceTest {
   }
 
   @Test
-  public void testTwoPhaseCommit() throws Exception {
+  void twoPhaseCommit() throws Exception {
     Xid xid = new CustomXid(1);
     xaRes.start(xid, XAResource.TMNOFLAGS);
     conn.createStatement().executeQuery("SELECT * FROM testxa1");
@@ -223,7 +220,7 @@ public class XADataSourceTest {
   }
 
   @Test
-  public void testCloseBeforeCommit() throws Exception {
+  void closeBeforeCommit() throws Exception {
     Xid xid = new CustomXid(5);
     xaRes.start(xid, XAResource.TMNOFLAGS);
     assertEquals(1, conn.createStatement().executeUpdate("INSERT INTO testxa1 VALUES (1)"));
@@ -237,7 +234,7 @@ public class XADataSourceTest {
   }
 
   @Test
-  public void testRecover() throws Exception {
+  void recover() throws Exception {
     Xid xid = new CustomXid(12345);
     xaRes.start(xid, XAResource.TMNOFLAGS);
     conn.createStatement().executeQuery("SELECT * FROM testxa1");
@@ -256,7 +253,7 @@ public class XADataSourceTest {
         }
       }
 
-      assertTrue("Did not recover prepared xid", recoveredXid);
+      assertTrue(recoveredXid, "Did not recover prepared xid");
       assertEquals(0, xaRes.recover(XAResource.TMNOFLAGS).length);
     }
 
@@ -274,12 +271,12 @@ public class XADataSourceTest {
         }
       }
 
-      assertFalse("Recovered rolled back xid", recoveredXid);
+      assertFalse(recoveredXid, "Recovered rolled back xid");
     }
   }
 
   @Test
-  public void testRollback() throws XAException {
+  void rollback() throws XAException {
     Xid xid = new CustomXid(3);
 
     xaRes.start(xid, XAResource.TMNOFLAGS);
@@ -289,7 +286,7 @@ public class XADataSourceTest {
   }
 
   @Test
-  public void testRollbackWithoutPrepare() throws XAException {
+  void rollbackWithoutPrepare() throws XAException {
     Xid xid = new CustomXid(4);
 
     xaRes.start(xid, XAResource.TMNOFLAGS);
@@ -298,7 +295,7 @@ public class XADataSourceTest {
   }
 
   @Test
-  public void testAutoCommit() throws Exception {
+  void autoCommit() throws Exception {
     Xid xid = new CustomXid(6);
 
     // When not in an XA transaction, autocommit should be true
@@ -341,13 +338,13 @@ public class XADataSourceTest {
 
     conn.createStatement().executeQuery("SELECT * FROM testxa1");
 
-    java.sql.Timestamp ts1 = getTransactionTimestamp(conn);
+    Timestamp ts1 = getTransactionTimestamp(conn);
 
     conn.close();
     conn = xaconn.getConnection();
     assertFalse(conn.getAutoCommit());
 
-    java.sql.Timestamp ts2 = getTransactionTimestamp(conn);
+    Timestamp ts2 = getTransactionTimestamp(conn);
 
     /*
      * Check that we're still in the same transaction. close+getConnection() should not rollback the
@@ -370,14 +367,14 @@ public class XADataSourceTest {
    * runs fast enough, and/or the server clock is very coarse grained. But it'll do for testing
    * purposes.</p>
    */
-  private static java.sql.Timestamp getTransactionTimestamp(Connection conn) throws SQLException {
+  private static Timestamp getTransactionTimestamp(Connection conn) throws SQLException {
     ResultSet rs = conn.createStatement().executeQuery("SELECT now()");
     rs.next();
     return rs.getTimestamp(1);
   }
 
   @Test
-  public void testEndThenJoin() throws XAException {
+  void endThenJoin() throws XAException {
     Xid xid = new CustomXid(5);
 
     xaRes.start(xid, XAResource.TMNOFLAGS);
@@ -388,7 +385,7 @@ public class XADataSourceTest {
   }
 
   @Test
-  public void testRestoreOfAutoCommit() throws Exception {
+  void restoreOfAutoCommit() throws Exception {
     conn.setAutoCommit(false);
 
     Xid xid = new CustomXid(14);
@@ -397,8 +394,8 @@ public class XADataSourceTest {
     xaRes.commit(xid, true);
 
     assertFalse(
-        "XaResource should have restored connection autocommit mode after commit or rollback to the initial state.",
-        conn.getAutoCommit());
+        conn.getAutoCommit(),
+        "XaResource should have restored connection autocommit mode after commit or rollback to the initial state.");
 
     // Test true case
     conn.setAutoCommit(true);
@@ -409,13 +406,13 @@ public class XADataSourceTest {
     xaRes.commit(xid, true);
 
     assertTrue(
-        "XaResource should have restored connection autocommit mode after commit or rollback to the initial state.",
-        conn.getAutoCommit());
+        conn.getAutoCommit(),
+        "XaResource should have restored connection autocommit mode after commit or rollback to the initial state.");
 
   }
 
   @Test
-  public void testRestoreOfAutoCommitEndThenJoin() throws Exception {
+  void restoreOfAutoCommitEndThenJoin() throws Exception {
     // Test with TMJOIN
     conn.setAutoCommit(true);
 
@@ -427,8 +424,8 @@ public class XADataSourceTest {
     xaRes.commit(xid, true);
 
     assertTrue(
-        "XaResource should have restored connection autocommit mode after start(TMNOFLAGS) end() start(TMJOIN) and then commit or rollback to the initial state.",
-        conn.getAutoCommit());
+        conn.getAutoCommit(),
+        "XaResource should have restored connection autocommit mode after start(TMNOFLAGS) end() start(TMJOIN) and then commit or rollback to the initial state.");
 
   }
 
@@ -438,7 +435,7 @@ public class XADataSourceTest {
    * transaction with identifier "blah" does not exist
    */
   @Test
-  public void testRepeatedRolledBack() throws Exception {
+  void repeatedRolledBack() throws Exception {
     Xid xid = new CustomXid(654321);
     xaRes.start(xid, XAResource.TMNOFLAGS);
     xaRes.end(xid, XAResource.TMSUCCESS);
@@ -450,8 +447,7 @@ public class XADataSourceTest {
       xaRes.rollback(xid);
       fail("Rollback was successful");
     } catch (XAException xae) {
-      assertEquals("Checking the errorCode is XAER_NOTA indicating the " + "xid does not exist.",
-          xae.errorCode, XAException.XAER_NOTA);
+      assertEquals(XAException.XAER_NOTA, xae.errorCode, "Checking the errorCode is XAER_NOTA indicating the " + "xid does not exist.");
     }
   }
 
@@ -460,7 +456,7 @@ public class XADataSourceTest {
    * with error code {@link XAException#XAER_PROTO}.
    */
   @Test
-  public void testPreparingPreparedXid() throws Exception {
+  void preparingPreparedXid() throws Exception {
     Xid xid = new CustomXid(1);
     xaRes.start(xid, XAResource.TMNOFLAGS);
     xaRes.end(xid, XAResource.TMSUCCESS);
@@ -469,8 +465,7 @@ public class XADataSourceTest {
       xaRes.prepare(xid);
       fail("Prepare is expected to fail with XAER_PROTO as xid was already prepared");
     } catch (XAException xae) {
-      assertEquals("Prepare call on already prepared xid " +  xid + " expects XAER_PROTO",
-          XAException.XAER_PROTO, xae.errorCode);
+      assertEquals(XAException.XAER_PROTO, xae.errorCode, "Prepare call on already prepared xid " + xid + " expects XAER_PROTO");
     } finally {
       xaRes.rollback(xid);
     }
@@ -481,7 +476,7 @@ public class XADataSourceTest {
    * with error code {@link XAException#XAER_NOTA}.
    */
   @Test
-  public void testCommittingCommittedXid() throws Exception {
+  void committingCommittedXid() throws Exception {
     Xid xid = new CustomXid(1);
     xaRes.start(xid, XAResource.TMNOFLAGS);
     xaRes.end(xid, XAResource.TMSUCCESS);
@@ -492,8 +487,7 @@ public class XADataSourceTest {
       xaRes.commit(xid, false);
       fail("Commit is expected to fail with XAER_NOTA as xid was already committed");
     } catch (XAException xae) {
-      assertEquals("Commit call on already committed xid " +  xid + " expects XAER_NOTA",
-          XAException.XAER_NOTA, xae.errorCode);
+      assertEquals(XAException.XAER_NOTA, xae.errorCode, "Commit call on already committed xid " + xid + " expects XAER_NOTA");
     }
   }
 
@@ -502,7 +496,7 @@ public class XADataSourceTest {
    * That different connection could be for example transaction manager recovery.
    */
   @Test
-  public void testCommitByDifferentConnection() throws Exception {
+  void commitByDifferentConnection() throws Exception {
     Xid xid = new CustomXid(1);
     xaRes.start(xid, XAResource.TMNOFLAGS);
     xaRes.end(xid, XAResource.TMSUCCESS);
@@ -525,8 +519,7 @@ public class XADataSourceTest {
       xaRes.commit(xid, false);
       fail("Commit is expected to fail with XAER_RMERR as somebody else already committed");
     } catch (XAException xae) {
-      assertEquals("Commit call on already committed xid " +  xid + " expects XAER_RMERR",
-          XAException.XAER_RMERR, xae.errorCode);
+      assertEquals(XAException.XAER_RMERR, xae.errorCode, "Commit call on already committed xid " + xid + " expects XAER_RMERR");
     }
   }
 
@@ -535,7 +528,7 @@ public class XADataSourceTest {
    * That different connection could be for example transaction manager recovery.
    */
   @Test
-  public void testRollbackByDifferentConnection() throws Exception {
+  void rollbackByDifferentConnection() throws Exception {
     Xid xid = new CustomXid(1);
     xaRes.start(xid, XAResource.TMNOFLAGS);
     xaRes.end(xid, XAResource.TMSUCCESS);
@@ -558,8 +551,7 @@ public class XADataSourceTest {
       xaRes.rollback(xid);
       fail("Rollback is expected to fail with XAER_RMERR as somebody else already rolled-back");
     } catch (XAException xae) {
-      assertEquals("Rollback call on already rolled-back xid " +  xid + " expects XAER_RMERR",
-          XAException.XAER_RMERR, xae.errorCode);
+      assertEquals(XAException.XAER_RMERR, xae.errorCode, "Rollback call on already rolled-back xid " + xid + " expects XAER_RMERR");
     }
   }
 
@@ -567,7 +559,7 @@ public class XADataSourceTest {
    * One-phase commit of prepared {@link Xid} should throw exception.
    */
   @Test
-  public void testOnePhaseCommitOfPrepared() throws Exception {
+  void onePhaseCommitOfPrepared() throws Exception {
     Xid xid = new CustomXid(1);
     xaRes.start(xid, XAResource.TMNOFLAGS);
     xaRes.end(xid, XAResource.TMSUCCESS);
@@ -577,8 +569,7 @@ public class XADataSourceTest {
       xaRes.commit(xid, true);
       fail("One-phase commit is expected to fail with XAER_PROTO when called on prepared xid");
     } catch (XAException xae) {
-      assertEquals("One-phase commit of prepared xid " +  xid + " expects XAER_PROTO",
-          XAException.XAER_PROTO, xae.errorCode);
+      assertEquals(XAException.XAER_PROTO, xae.errorCode, "One-phase commit of prepared xid " + xid + " expects XAER_PROTO");
     }
   }
 
@@ -587,7 +578,7 @@ public class XADataSourceTest {
    * {@link XAException} being thrown with error code {@link XAException#XAER_NOTA}.
    */
   @Test
-  public void testOnePhaseCommittingCommittedXid() throws Exception {
+  void onePhaseCommittingCommittedXid() throws Exception {
     Xid xid = new CustomXid(1);
     xaRes.start(xid, XAResource.TMNOFLAGS);
     xaRes.end(xid, XAResource.TMSUCCESS);
@@ -597,8 +588,7 @@ public class XADataSourceTest {
       xaRes.commit(xid, true);
       fail("One-phase commit is expected to fail with XAER_NOTA as xid was already committed");
     } catch (XAException xae) {
-      assertEquals("One-phase commit call on already committed xid " +  xid + " expects XAER_NOTA",
-          XAException.XAER_NOTA, xae.errorCode);
+      assertEquals(XAException.XAER_NOTA, xae.errorCode, "One-phase commit call on already committed xid " + xid + " expects XAER_NOTA");
     }
   }
 
@@ -607,14 +597,13 @@ public class XADataSourceTest {
    * is {@link XAException#XAER_NOTA}.
    */
   @Test
-  public void testPrepareUnknownXid() throws Exception {
+  void prepareUnknownXid() throws Exception {
     Xid xid = new CustomXid(1);
     try {
       xaRes.prepare(xid);
       fail("Prepare is expected to fail with XAER_NOTA as used unknown xid");
     } catch (XAException xae) {
-      assertEquals("Prepare call on unknown xid " +  xid + " expects XAER_NOTA",
-          XAException.XAER_NOTA, xae.errorCode);
+      assertEquals(XAException.XAER_NOTA, xae.errorCode, "Prepare call on unknown xid " + xid + " expects XAER_NOTA");
     }
   }
 
@@ -623,7 +612,7 @@ public class XADataSourceTest {
    * is {@link XAException#XAER_NOTA}.
    */
   @Test
-  public void testCommitUnknownXid() throws Exception {
+  void commitUnknownXid() throws Exception {
     Xid xid = new CustomXid(1);
     Xid unknownXid = new CustomXid(42);
     xaRes.start(xid, XAResource.TMNOFLAGS);
@@ -633,8 +622,7 @@ public class XADataSourceTest {
       xaRes.commit(unknownXid, false);
       fail("Commit is expected to fail with XAER_NOTA as used unknown xid");
     } catch (XAException xae) {
-      assertEquals("Commit call on unknown xid " +  unknownXid + " expects XAER_NOTA",
-          XAException.XAER_NOTA, xae.errorCode);
+      assertEquals(XAException.XAER_NOTA, xae.errorCode, "Commit call on unknown xid " + unknownXid + " expects XAER_NOTA");
     } finally {
       xaRes.rollback(xid);
     }
@@ -645,7 +633,7 @@ public class XADataSourceTest {
    * the expected {@link XAException#errorCode} is {@link XAException#XAER_NOTA}.
    */
   @Test
-  public void testOnePhaseCommitUnknownXid() throws Exception {
+  void onePhaseCommitUnknownXid() throws Exception {
     Xid xid = new CustomXid(1);
     Xid unknownXid = new CustomXid(42);
     xaRes.start(xid, XAResource.TMNOFLAGS);
@@ -654,8 +642,7 @@ public class XADataSourceTest {
       xaRes.commit(unknownXid, true);
       fail("One-phase commit is expected to fail with XAER_NOTA as used unknown xid");
     } catch (XAException xae) {
-      assertEquals("Commit call on unknown xid " +  unknownXid + " expects XAER_NOTA",
-          XAException.XAER_NOTA, xae.errorCode);
+      assertEquals(XAException.XAER_NOTA, xae.errorCode, "Commit call on unknown xid " + unknownXid + " expects XAER_NOTA");
     } finally {
       xaRes.rollback(xid);
     }
@@ -666,7 +653,7 @@ public class XADataSourceTest {
    * is {@link XAException#XAER_NOTA}.
    */
   @Test
-  public void testRollbackUnknownXid() throws Exception {
+  void rollbackUnknownXid() throws Exception {
     Xid xid = new CustomXid(1);
     Xid unknownXid = new CustomXid(42);
     xaRes.start(xid, XAResource.TMNOFLAGS);
@@ -676,8 +663,7 @@ public class XADataSourceTest {
       xaRes.rollback(unknownXid);
       fail("Rollback is expected to fail as used unknown xid");
     } catch (XAException xae) {
-      assertEquals("Commit call on unknown xid " +  unknownXid + " expects XAER_NOTA",
-          XAException.XAER_NOTA, xae.errorCode);
+      assertEquals(XAException.XAER_NOTA, xae.errorCode, "Commit call on unknown xid " + unknownXid + " expects XAER_NOTA");
     } finally {
       xaRes.rollback(xid);
     }
@@ -688,7 +674,7 @@ public class XADataSourceTest {
    * Resource manager can't expect state of the {@link Xid}.
    */
   @Test
-  public void testDatabaseRemovesPreparedBeforeCommit() throws Exception {
+  void databaseRemovesPreparedBeforeCommit() throws Exception {
     Xid xid = new CustomXid(1);
     xaRes.start(xid, XAResource.TMNOFLAGS);
     xaRes.end(xid, XAResource.TMSUCCESS);
@@ -700,8 +686,7 @@ public class XADataSourceTest {
       xaRes.commit(xid, false);
       fail("Commit is expected to fail as committed xid was removed before");
     } catch (XAException xae) {
-      assertEquals("Commit call on xid " +  xid + " not known to DB expects XAER_RMERR",
-          XAException.XAER_RMERR, xae.errorCode);
+      assertEquals(XAException.XAER_RMERR, xae.errorCode, "Commit call on xid " + xid + " not known to DB expects XAER_RMERR");
     }
   }
 
@@ -710,7 +695,7 @@ public class XADataSourceTest {
    * Resource manager can't expect state of the {@link Xid}.
    */
   @Test
-  public void testDatabaseRemovesPreparedBeforeRollback() throws Exception {
+  void databaseRemovesPreparedBeforeRollback() throws Exception {
     Xid xid = new CustomXid(1);
     xaRes.start(xid, XAResource.TMNOFLAGS);
     xaRes.end(xid, XAResource.TMSUCCESS);
@@ -722,8 +707,7 @@ public class XADataSourceTest {
       xaRes.rollback(xid);
       fail("Rollback is expected to fail as committed xid was removed before");
     } catch (XAException xae) {
-      assertEquals("Rollback call on xid " +  xid + " not known to DB expects XAER_RMERR",
-          XAException.XAER_RMERR, xae.errorCode);
+      assertEquals(XAException.XAER_RMERR, xae.errorCode, "Rollback call on xid " + xid + " not known to DB expects XAER_RMERR");
     }
   }
 
@@ -732,7 +716,7 @@ public class XADataSourceTest {
    * {@link XAException} error code {@link XAException#XAER_RMFAIL} is expected.
    */
   @Test
-  public void testNetworkIssueOnCommit() throws Exception {
+  void networkIssueOnCommit() throws Exception {
     Xid xid = new CustomXid(1);
     xaRes.start(xid, XAResource.TMNOFLAGS);
     xaRes.end(xid, XAResource.TMSUCCESS);
@@ -744,8 +728,7 @@ public class XADataSourceTest {
       xaRes.commit(xid, false);
       fail("Commit is expected to fail as connection was closed");
     } catch (XAException xae) {
-      assertEquals("Commit call on closed connection expects XAER_RMFAIL",
-          XAException.XAER_RMFAIL, xae.errorCode);
+      assertEquals(XAException.XAER_RMFAIL, xae.errorCode, "Commit call on closed connection expects XAER_RMFAIL");
     }
   }
 
@@ -754,7 +737,7 @@ public class XADataSourceTest {
    * {@link XAException} error code {@link XAException#XAER_RMFAIL} is expected.
    */
   @Test
-  public void testNetworkIssueOnOnePhaseCommit() throws Exception {
+  void networkIssueOnOnePhaseCommit() throws Exception {
     Xid xid = new CustomXid(1);
     xaRes.start(xid, XAResource.TMNOFLAGS);
     xaRes.end(xid, XAResource.TMSUCCESS);
@@ -765,8 +748,7 @@ public class XADataSourceTest {
       xaRes.commit(xid, true);
       fail("One-phase commit is expected to fail as connection was closed");
     } catch (XAException xae) {
-      assertEquals("One-phase commit call on closed connection expects XAER_RMFAIL",
-          XAException.XAER_RMFAIL, xae.errorCode);
+      assertEquals(XAException.XAER_RMFAIL, xae.errorCode, "One-phase commit call on closed connection expects XAER_RMFAIL");
     }
   }
 
@@ -775,7 +757,7 @@ public class XADataSourceTest {
    * {@link XAException} error code {@link XAException#XAER_RMFAIL} is expected.
    */
   @Test
-  public void testNetworkIssueOnRollback() throws Exception {
+  void networkIssueOnRollback() throws Exception {
     Xid xid = new CustomXid(1);
     xaRes.start(xid, XAResource.TMNOFLAGS);
     xaRes.end(xid, XAResource.TMSUCCESS);
@@ -787,8 +769,7 @@ public class XADataSourceTest {
       xaRes.rollback(xid);
       fail("Rollback is expected to fail as connection was closed");
     } catch (XAException xae) {
-      assertEquals("Rollback call on closed connection expects XAER_RMFAIL",
-          XAException.XAER_RMFAIL, xae.errorCode);
+      assertEquals(XAException.XAER_RMFAIL, xae.errorCode, "Rollback call on closed connection expects XAER_RMFAIL");
     }
   }
 
@@ -797,7 +778,7 @@ public class XADataSourceTest {
    * mapped to the correct XA Error Code
    */
   @Test
-  public void testMappingOfConstraintViolations() throws Exception {
+  void mappingOfConstraintViolations() throws Exception {
     Xid xid = new CustomXid(1);
     xaRes.start(xid, XAResource.TMNOFLAGS);
     assertEquals(0, conn.createStatement().executeUpdate("SET CONSTRAINTS ALL DEFERRED"));
@@ -809,8 +790,7 @@ public class XADataSourceTest {
 
       fail("Prepare is expected to fail as an integrity violation occurred");
     } catch (XAException xae) {
-      assertEquals("Prepare call with deferred constraints violations expects XA_RBINTEGRITY",
-          XAException.XA_RBINTEGRITY, xae.errorCode);
+      assertEquals(XAException.XA_RBINTEGRITY, xae.errorCode, "Prepare call with deferred constraints violations expects XA_RBINTEGRITY");
     }
   }
 
